==> af-api-1.1.11.3-sources.jar: com/af/v4/system/api/factory/RemoteUserFallbackFactory.java <==
package com.af.v4.system.api.factory;

import com.af.v4.system.api.RemoteUserService;
import com.af.v4.system.api.domain.SysUser;
import com.af.v4.system.api.model.LoginUser;
import com.af.v4.system.common.core.domain.R;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.openfeign.FallbackFactory;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * 用户服务降级处理
 */
@Component
public class RemoteUserFallbackFactory implements FallbackFactory<RemoteUserService> {
    private static final Logger log = LoggerFactory.getLogger(RemoteUserFallbackFactory.class);

    @Override
    public RemoteUserService create(Throwable throwable) {
        log.error("用户服务调用失败", throwable);
        return new RemoteUserService() {
            @Override
            public R<LoginUser> getUserInfo(String username, String resourceName, boolean isMobile, String source) {
                return R.fail("获取用户失败:" + throwable.getMessage());
            }

            @Override
            public R<Map<String, Object>> logout(String source) {
                return R.fail("用户登出失败:" + throwable.getMessage());
            }

            @Override
            public R<Boolean> registerUserInfo(SysUser sysUser, String source) {
                return R.fail("注册用户失败:" + throwable.getMessage());
            }

            @Override
            public R<LoginUser> getWxUserInfo(String openid, String source) {
                return R.fail("微信标识获取用户失败:" + throwable.getMessage());
            }
        };
    }
}

==> af-api-1.1.14.4-sources.jar: com/af/v4/system/api/factory/RemoteUserFallbackFactory.java <==
package com.af.v4.system.api.factory;

import com.af.v4.system.api.RemoteUserService;
import com.af.v4.system.api.domain.SysUser;
import com.af.v4.system.api.model.LoginUser;
import com.af.v4.system.common.core.domain.R;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.openfeign.FallbackFactory;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * 用户服务降级处理
 */
@Component
public class RemoteUserFallbackFactory implements FallbackFactory<RemoteUserService> {
    private static final Logger log = LoggerFactory.getLogger(RemoteUserFallbackFactory.class);

    @Override
    public RemoteUserService create(Throwable throwable) {
        log.error("用户服务调用失败", throwable);
        return new RemoteUserService() {
            @Override
            public R<LoginUser> getUserInfo(String username, String resourceName, boolean isMobile, String source) {
                return R.fail("获取用户失败:" + throwable.getMessage());
            }

            @Override
            public R<Map<String, Object>> logout(String source) {
                return R.fail("用户登出失败:" + throwable.getMessage());
            }

            @Override
            public R<Boolean> registerUserInfo(SysUser sysUser, String source) {
                return R.fail("注册用户失败:" + throwable.getMessage());
            }

            @Override
            public R<LoginUser> getWxUserInfo(String openid, String resourceName, boolean isMobile, String source) {
                return R.fail("微信标识获取用户失败:" + throwable.getMessage());
            }
        };
    }
}
